@@ -321,7 +321,8 @@ double den_cpp(int x, int y, int n, NumericVector p) {
   double Pr = p[2] + p[3];  // total prob of response
 
   double Pt = p[1] + p[3];  // total prob of toxicity
-
+  (void) Pt; // ← Add this if you're not using Pt
+  
   double Pt_1 = p[3] / Pr;  // condition toxicity from response patients p(0|1)
 
   double Pt_0 = p[1] / (1 - Pr);  // condition toxicity from non-response patients p(0|0)
@@ -428,6 +429,7 @@ List efftox_recursive_optim(NumericVector interm, IntegerVector npt, NumericVect
 
     int n = npt[n_c - 1];
     int n_obs = interm[n_c - 1];
+    (void) n_obs;
     // Rcpp::Rcout << "n_stage1: " << n << std::endl;
 
     // get nonstop/go event counts:
@@ -463,7 +465,8 @@ List efftox_recursive_optim(NumericVector interm, IntegerVector npt, NumericVect
     int n = npt[n_c - 1];
     int n_obs = interm[n_c - 1];
     int n_obs_prev = interm[n_c - 2];
-
+    (void)n_obs_prev;  // ← This tells the compiler: I know it's unused
+    
     // get nonstop/go event counts:
     int b_eff = bound_eff[n_c - 1];
     int b_eff_prev = bound_eff[n_c - 2];
