@@ -5,6 +5,8 @@
 #include <RcppArmadillo.h>
 #include <math.h>
 #include <Rmath.h>
+#include "GBOP2_types.h"
+
 using namespace Rcpp;
 
 
@@ -176,23 +178,23 @@ List Exacterror(NumericVector nobs, NumericVector ncut, double pnull, double pal
   return result;
 }
 
-// Define a struct to hold the data
-struct Data {
-  std::vector<int> num_event;
-  std::vector<double> prob;
-};
-
-// Define a struct to hold the result
-struct Result {
-  Data nonstopping_df_null;
-  Data nonstopping_df_alter;
-  double nonstop_prob_null;
-  double nonstop_prob_alter;
-  double expected_size;
-};
+// // Define a struct to hold the data
+// struct Data {
+//   std::vector<int> num_event;
+//   std::vector<double> prob;
+// };
+// 
+// // Define a struct to hold the result
+// struct Result {
+//   Data nonstopping_df_null;
+//   Data nonstopping_df_alter;
+//   double nonstop_prob_null;
+//   double nonstop_prob_alter;
+//   double expected_size;
+// };
 
 // Function to calculate exact error recursively
-Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut, double pnull, int ntotal) {
+Result_singleE exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut, double pnull, int ntotal) {
   int n_c = nobs.size();
   double ptsa = 0;
   
@@ -230,7 +232,7 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
       ptsa = ptsa + nonstop_prob_null * nobs[0];
     }
     
-    Result res_list;
+    Result_singleE res_list;
     res_list.nonstopping_df_null = nonstopping_df_null;
     res_list.nonstop_prob_null = nonstop_prob_null;
     res_list.expected_size = ptsa;
@@ -238,7 +240,9 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
     return res_list;
   } else {
     Rcpp::NumericVector nobs_new(nobs.begin(), nobs.end() - 1);
-    Result res_before = exact_error_recursive2(nobs_new, ncut, pnull, ntotal);
+    //Result res_before = exact_error_recursive2(nobs_new, ncut, pnull, ntotal);
+    Result_singleE res_before = exact_error_recursive2(nobs_new, ncut, pnull, ntotal);
+    
     Data nonstop_null = res_before.nonstopping_df_null;
     ptsa = res_before.expected_size;
     
@@ -246,7 +250,9 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
     // pnull
     Data nonstop_df_new_null;
     // std::map<int, double> sum_map_null;
-    for (int i = 0; i < nonstop_null.num_event.size(); i++) {
+    //for (int i = 0; i < nonstop_null.num_event.size(); i++) {
+    for (std::size_t i = 0; i < nonstop_null.num_event.size(); i++){
+      
       std::vector<int> newevent;
       for (int x = ncut[n_c-1] + 1; x <= nobs[n_c-1]; x++) {
         int adjusted_x = x - nonstop_null.num_event[i];
@@ -266,7 +272,9 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
       int nobs_diff = nobs[n_c - 1] - nobs[n_c - 2];
       
       Data newdf;
-      for (int j = 0; j < newevent.size(); j++) {
+      //for (int j = 0; j < newevent.size(); j++) {
+      for (std::size_t j = 0; j < newevent.size(); j++){
+        
         int new_event_value = nonstop_null.num_event[i] + newevent[j];
         double dbinom_result = R::dbinom(newevent[j], nobs_diff, pnull, false);
         
@@ -286,7 +294,8 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
     // Create a hashmap to store num_event as keys and their corresponding index in nonstop_df_new_sum as values
     std::unordered_map<int, int> num_event_index_map_null;
     
-    for (int i = 0; i < nonstop_df_new_null.num_event.size(); i++) {
+   // for (int i = 0; i < nonstop_df_new_null.num_event.size(); i++) {
+   for (std::size_t i = 0; i < nonstop_df_new_null.num_event.size(); i++){
       int current_num_event = nonstop_df_new_null.num_event[i];
       auto it = num_event_index_map_null.find(current_num_event);
       
@@ -303,7 +312,9 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
     
     // nonstopping * stopping:
     // Data nonstop_df_new_stop;
-    for (int i = 0; i < nonstop_null.num_event.size(); i++) {
+    //for (int i = 0; i < nonstop_null.num_event.size(); i++) {
+    for (std::size_t i = 0; i < nonstop_null.num_event.size(); i++){
+      
       std::vector<int> newevent;
       for (int x = ncut[n_c - 2] + 1; x <= ncut[n_c-1]; x++) {
         int adjusted_x = x - nonstop_null.num_event[i];
@@ -322,7 +333,9 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
       int nobs_diff = nobs[n_c - 1] - nobs[n_c - 2];
       
       Data newdf;
-      for (int j = 0; j < newevent.size(); j++) {
+      //for (int j = 0; j < newevent.size(); j++) {
+      for (std::size_t j = 0; j < newevent.size(); j++){
+        
         int new_event_value = nonstop_null.num_event[i] + newevent[j];
         double dbinom_result = R::dbinom(newevent[j], nobs_diff, pnull, false);
         
@@ -338,7 +351,7 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
     
     // ptsa = ptsa + nonstop_prob_alter * nobs[n_c];
     
-    Result res_list;
+    Result_singleE res_list;
     res_list.nonstopping_df_null = nonstop_df_new_null_sum;
     res_list.nonstop_prob_null = nonstop_prob_null;
     res_list.expected_size = ptsa;
@@ -350,8 +363,10 @@ Result exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut
 // [[Rcpp::export]]
 List exact_error_recursive2_Rcpp(Rcpp::NumericVector nobs, Rcpp::NumericVector ncut, double pnull, double palter, int ntotal) {
   // Call the C++ function
-  Result result = exact_error_recursive2(nobs, ncut, pnull, ntotal);
-  Result result_H1 = exact_error_recursive2(nobs, ncut, palter, ntotal);
+  // Result result = exact_error_recursive2(nobs, ncut, pnull, ntotal);
+  // Result result_H1 = exact_error_recursive2(nobs, ncut, palter, ntotal);
+  Result_singleE result = exact_error_recursive2(nobs, ncut, pnull, ntotal);
+  Result_singleE result_H1 = exact_error_recursive2(nobs, ncut, palter, ntotal);
   
   // Convert Result to Rcpp List
   List result_list = List::create(
@@ -494,7 +509,7 @@ NumericMatrix GridSearchBiRcpp(int seed, NumericMatrix contrast, NumericVector n
 {
   List temp1;
   List temp2;
-  int k1=cutstart-1;
+  //int k1=cutstart-1;
   NumericVector ocmatbinary_v(6);
   NumericMatrix ocmatbinary(6,1);
   
@@ -506,15 +521,15 @@ NumericMatrix GridSearchBiRcpp(int seed, NumericMatrix contrast, NumericVector n
       for (int k = 0; k<pow.size(); k++)
       {
         
-        k1=k;
+       // k1=k;
         double b_mid1=b1[j];
         double b_mid2=b2[l];
         double pow_mid=pow[k];
         
         temp1=GetocBiRcpp(seed, nsim, contrast, nobs, b_mid1, b_mid2, pow_mid, dprior, pa, pn, ffff);
-        double temp1_accept = temp1[1];
+        // double temp1_accept = temp1[1];
         //double temp1_pts = temp1[3]/nobs[nobs.size()-1];
-        double temp1_pts = static_cast<double>(temp1[3]) / static_cast<double>(nobs[nobs.size() - 1]);
+        // double temp1_pts = static_cast<double>(temp1[3]) / static_cast<double>(nobs[nobs.size() - 1]);
         
         
         
